########## R function: graphicCompareCIs ##########

# For generation of example generalized linear mixed 
# model data.

# Last changed: 30 OCT 2020

graphicCompareCIs <- function(betaMLE,SDbetaMLE,SDbetaJWB,beta0True,betaBTrue)
{
   # Set plotting values:

   lwdVal <- 3
   colVec <- c("blue","darkorange")

   # Extract the number of confidence interval pairs:

   numCIpairs <- length(betaMLE)

   # Compute the lower and upper confidence interval limits:

   lowXCT <- betaMLE - qnorm(0.975)*SDbetaXCT
   uppXCT <- betaMLE + qnorm(0.975)*SDbetaXCT

   lowJWB <- betaMLE - qnorm(0.975)*SDbetaJWB
   uppJWB <- betaMLE + qnorm(0.975)*SDbetaJWB

   # Set up vertical grid:

   yGrid <- seq(0,1,length=(numCIpairs + 1))[-1]

   # Set shift amount:

   shftAmt <- 0.075*(yGrid[2] - yGrid[1])

   # Plot each of the 95% confidence intervals:

   xlimVal <- range(c(lowXCT,uppXCT,lowJWB,uppJWB))

   xTextPos <- 1.1*xlimVal[1] - 0.1*xlimVal[2]
   xLineLow <- 1.05*xlimVal[1] - 0.05*xlimVal[2]

   plot(0,type="n",xlim=xlimVal,ylim=c(0,1.2),bty="l",yaxt="n",
        xlab="fixed effects",ylab="")

   par(xpd=TRUE)

   for (iCI in 1:numCIpairs)
   {
      indxForYpos <- numCIpairs - iCI + 1

      if (iCI==1) parmCurr <- expression(beta[0])
      if (iCI>1) parmCurr <- bquote(beta[paste("B",.(iCI-1))])

      text(xTextPos,yGrid[indxForYpos],parmCurr,cex=1.5)
      lines(c(lowXCT[iCI],uppXCT[iCI]),rep(yGrid[indxForYpos]+shftAmt,2),
            col=colVec[1],lwd=lwdVal)  
      lines(c(lowJWB[iCI],uppJWB[iCI]),rep(yGrid[indxForYpos]-shftAmt,2),
            col=colVec[2],lwd=lwdVal)  
      lines(c(xLineLow,xlimVal[2]),rep(yGrid[indxForYpos],2),col="grey",lty=2)
   }

   # Add a legend:

   #The legend() call commented out and replaced by code below due to
   #inexclibable problem with Rstudio graphics. 
   #legend("topright",legend=c("exact","J.W.B. theory"),col=colVec,lwd=lwdVal)
   xLegVec <- c(0.3*xlimVal[1] + 0.7*xlimVal[2],0.2*xlimVal[1] + 0.8*xlimVal[2],
                0.17*xlimVal[1] + 0.83*xlimVal[2])
   yLegUpp <- 1.2   ;   yLegLow <- 1.15
   lines(c(xLegVec[1],xLegVec[2]),rep(yLegUpp,2),col=colVec[1],lwd=lwdVal)
   text(xLegVec[3],yLegUpp,"exact",adj=0)
   lines(c(xLegVec[1],xLegVec[2]),rep(yLegLow,2),col=colVec[2],lwd=lwdVal)
   text(xLegVec[3],yLegLow,"J.W.B. theory",adj=0)

   invisible()
}

############ End of graphicCompareCIs  ############
